Module CLEAR

Module CLEAR 

CLEAR [...]

Purpose

Clear all variables.

Remarks

This statement will ignore any options. Other versions of basic use these options to define memory limits for the program, stack, strings, etc.

Example

CLEAR
CLEAR ,16384,1000